@@ -1,12 +1,15 @@
+from django.utils.translation import gettext_lazy as _
+
 from allianceauth import hooks
 from allianceauth.services.hooks import UrlHook, MenuItemHook
 
 from . import urls
+from .models import StandingFilter
 
 
 class AAContactsHook(MenuItemHook):
     def __init__(self):
-        super().__init__("Contacts", "fas fa-address-book", "aa_contacts:index", navactive=['aa_contacts:'])
+        super().__init__(_("Contacts"), "fas fa-address-book", "aa_contacts:index", navactive=['aa_contacts:'])
 
 
 @hooks.register('menu_item_hook')
@@ -16,9 +19,14 @@ def register_menu():
 
 @hooks.register('url_hook')
 def register_urls():
-    return UrlHook(urls, 'aa_contacts', 'aa_contacts/')
+    return UrlHook(urls, 'aa_contacts', r'^contacts/')
 
 
 @hooks.register('charlink')
 def register_charlink_hook():
-    return 'aa_contacts.charlink_hook.app_import'
+    return 'aa_contacts.charlink_hook'
+
+
+@hooks.register('secure_group_filters')
+def filters():
+    return [StandingFilter]
