@@ -1,12 +1,16 @@
-from django.urls import path
+from django.urls import path, re_path
 
 from . import views
+from .api import api
 
 app_name = 'aa_contacts'
 
 
 urlpatterns = [
     path('', views.index, name='index'),
+    path('dashboard/', views.dashboard, name='dashboard'),
+    path('api/', api.urls),
+    re_path('^r/', views.react_view, name='react_view'),
     path('alliance/<int:alliance_pk>/', views.alliance_contacts, name='alliance_contacts'),
     path('alliance/add_token/', views.add_alliance_token, name='add_alliance_token'),
     path('alliance/update/<int:alliance_pk>/', views.update_alliance, name='update_alliance'),
